var examples =
[
    [ "Algebraic_kernel_d/Construct_algebraic_real_1.cpp", "Algebraic_kernel_d_2Construct_algebraic_real_1_8cpp-example.html", null ],
    [ "Algebraic_kernel_d/Solve_1.cpp", "Algebraic_kernel_d_2Solve_1_8cpp-example.html", null ],
    [ "Algebraic_kernel_d/Compare_1.cpp", "Algebraic_kernel_d_2Compare_1_8cpp-example.html", null ],
    [ "Algebraic_kernel_d/Isolate_1.cpp", "Algebraic_kernel_d_2Isolate_1_8cpp-example.html", null ],
    [ "Algebraic_kernel_d/Sign_at_1.cpp", "Algebraic_kernel_d_2Sign_at_1_8cpp-example.html", null ]
];